@@ -36,10 +36,10 @@ Locater::Locater(TQObject *parent, const char *name)
 {
 	kdDebug(7134) << "Locater::Locater" << endl;
 
-	connect(&m_process, TQT_SIGNAL(processExited(TDEProcess*)),
-			 this, TQT_SLOT(finished(TDEProcess*)));
-	connect(&m_process, TQT_SIGNAL(readReady(KProcIO*)),
-			 this, TQT_SLOT(gotOutput(KProcIO*)));
+	connect(&m_process, TQ_SIGNAL(processExited(TDEProcess*)),
+			 this, TQ_SLOT(finished(TDEProcess*)));
+	connect(&m_process, TQ_SIGNAL(readReady(KProcIO*)),
+			 this, TQ_SLOT(gotOutput(KProcIO*)));
 
 	setupLocate();
 }
