@@ -1009,7 +1009,7 @@ LocateItem::LocateItem(const TQString& path, int subItems)
 /////////////////////////////////////////////////////////////////////
 // INVOKATION
 
-extern "C" { KDE_EXPORT int kdemain(int argc, char **argv); }
+extern "C" { TDE_EXPORT int kdemain(int argc, char **argv); }
 
 extern "C"
 {
